==> 1.0.2.tar.gz: doc/WireguardApi.md <==
# forestvpn_api.api.WireguardApi

## Load the API package
```dart
import 'package:forestvpn_api/api.dart';
```

All URIs are relative to *https://api.forestvpn.com/v1*

Method | HTTP request | Description
------------- | ------------- | -------------
[**createProfile**](WireguardApi.md#createProfile) | **POST** /wg/profiles/ | Create new WireGuard profile
[**deleteProfile**](WireguardApi.md#deleteProfile) | **DELETE** /wg/profiles/{profileId}/ | Delete WireGuarg profile
[**getPeers**](WireguardApi.md#getPeers) | **GET** /wg/peers/ | Retrieve Wireguard peers
[**getProfile**](WireguardApi.md#getProfile) | **GET** /wg/profile/ | Retrieve VPN profile
[**getProfileByID**](WireguardApi.md#getProfileByID) | **GET** /wg/profiles/{profileId}/ | Retrieve WireGuarg profile
[**getProfiles**](WireguardApi.md#getProfiles) | **GET** /wg/profiles/ | Retrieve list of WireGuard profiles


# **createProfile**
> WireguardProfile createProfile(request)

Create new WireGuard profile

### Example 
```dart
import 'package:forestvpn_api/api.dart';
// TODO Configure API key authorization: Bearer
//forestvpn_api.api.Configuration.apiKey{'Authorization'} = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//forestvpn_api.api.Configuration.apiKeyPrefix{'Authorization'} = "Bearer";

var api_instance = new WireguardApi();
var request = new WireGuardProfileCreateRequest(); // WireGuardProfileCreateRequest | 

try { 
    var result = api_instance.createProfile(request);
    print(result);
} catch (e) {
    print("Exception when calling WireguardApi->createProfile: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **request** | [**WireGuardProfileCreateRequest**](WireGuardProfileCreateRequest.md)|  | [optional] 

### Return type

[**WireguardProfile**](WireguardProfile.md)

### Authorization

[Bearer](../README.md#Bearer)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **deleteProfile**
> deleteProfile(profileId)

Delete WireGuarg profile

### Example 
```dart
import 'package:forestvpn_api/api.dart';
// TODO Configure API key authorization: Bearer
//forestvpn_api.api.Configuration.apiKey{'Authorization'} = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//forestvpn_api.api.Configuration.apiKeyPrefix{'Authorization'} = "Bearer";

var api_instance = new WireguardApi();
var profileId = ; // String | 

try { 
    api_instance.deleteProfile(profileId);
} catch (e) {
    print("Exception when calling WireguardApi->deleteProfile: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **profileId** | [**String**](.md)|  | 

### Return type

void (empty response body)

### Authorization

[Bearer](../README.md#Bearer)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **getPeers**
> List<WireguardPeer> getPeers(timestamp)

Retrieve Wireguard peers

### Example 
```dart
import 'package:forestvpn_api/api.dart';
// TODO Configure API key authorization: Bearer
//forestvpn_api.api.Configuration.apiKey{'Authorization'} = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//forestvpn_api.api.Configuration.apiKeyPrefix{'Authorization'} = "Bearer";

var api_instance = new WireguardApi();
var timestamp = 56; // int | 

try { 
    var result = api_instance.getPeers(timestamp);
    print(result);
} catch (e) {
    print("Exception when calling WireguardApi->getPeers: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **timestamp** | **int**|  | [optional] 

### Return type

[**List<WireguardPeer>**](WireguardPeer.md)

### Authorization

[Bearer](../README.md#Bearer)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **getProfile**
> WireguardProfile getProfile()

Retrieve VPN profile

### Example 
```dart
import 'package:forestvpn_api/api.dart';
// TODO Configure API key authorization: Bearer
//forestvpn_api.api.Configuration.apiKey{'Authorization'} = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//forestvpn_api.api.Configuration.apiKeyPrefix{'Authorization'} = "Bearer";

var api_instance = new WireguardApi();

try { 
    var result = api_instance.getProfile();
    print(result);
} catch (e) {
    print("Exception when calling WireguardApi->getProfile: $e\n");
}
```

### Parameters
This endpoint does not need any parameter.

### Return type

[**WireguardProfile**](WireguardProfile.md)

### Authorization

[Bearer](../README.md#Bearer)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **getProfileByID**
> WireguardProfile getProfileByID(profileId)

Retrieve WireGuarg profile

### Example 
```dart
import 'package:forestvpn_api/api.dart';
// TODO Configure API key authorization: Bearer
//forestvpn_api.api.Configuration.apiKey{'Authorization'} = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//forestvpn_api.api.Configuration.apiKeyPrefix{'Authorization'} = "Bearer";

var api_instance = new WireguardApi();
var profileId = ; // String | 

try { 
    var result = api_instance.getProfileByID(profileId);
    print(result);
} catch (e) {
    print("Exception when calling WireguardApi->getProfileByID: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **profileId** | [**String**](.md)|  | 

### Return type

[**WireguardProfile**](WireguardProfile.md)

### Authorization

[Bearer](../README.md#Bearer)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **getProfiles**
> List<WireguardProfile> getProfiles()

Retrieve list of WireGuard profiles

### Example 
```dart
import 'package:forestvpn_api/api.dart';
// TODO Configure API key authorization: Bearer
//forestvpn_api.api.Configuration.apiKey{'Authorization'} = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//forestvpn_api.api.Configuration.apiKeyPrefix{'Authorization'} = "Bearer";

var api_instance = new WireguardApi();

try { 
    var result = api_instance.getProfiles();
    print(result);
} catch (e) {
    print("Exception when calling WireguardApi->getProfiles: $e\n");
}
```

### Parameters
This endpoint does not need any parameter.

### Return type

[**List<WireguardProfile>**](WireguardProfile.md)

### Authorization

[Bearer](../README.md#Bearer)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

==> 1.0.3.tar.gz: doc/WireguardApi.md <==
# forestvpn_api.api.WireguardApi

## Load the API package
```dart
import 'package:forestvpn_api/api.dart';
```

All URIs are relative to *https://api.forestvpn.com/v1*

Method | HTTP request | Description
------------- | ------------- | -------------
[**createProfile**](WireguardApi.md#createProfile) | **POST** /wg/profiles/ | Create new WireGuard profile
[**deleteProfile**](WireguardApi.md#deleteProfile) | **DELETE** /wg/profiles/{profileId}/ | Delete WireGuarg profile
[**getPeers**](WireguardApi.md#getPeers) | **GET** /wg/peers/ | Retrieve Wireguard peers
[**getProfile**](WireguardApi.md#getProfile) | **GET** /wg/profile/ | Retrieve VPN profile
[**getProfileByID**](WireguardApi.md#getProfileByID) | **GET** /wg/profiles/{profileId}/ | Retrieve WireGuarg profile
[**getProfiles**](WireguardApi.md#getProfiles) | **GET** /wg/profiles/ | Retrieve list of WireGuard profiles


# **createProfile**
> WireguardProfile createProfile(request)

Create new WireGuard profile

### Example 
```dart
import 'package:forestvpn_api/api.dart';
// TODO Configure API key authorization: Bearer
//defaultApiClient.getAuthentication<ApiKeyAuth>('Bearer').apiKey = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//defaultApiClient.getAuthentication<ApiKeyAuth>('Bearer').apiKeyPrefix = 'Bearer';

var api_instance = WireguardApi();
var request = WireGuardProfileCreateRequest(); // WireGuardProfileCreateRequest | 

try { 
    var result = api_instance.createProfile(request);
    print(result);
} catch (e) {
    print("Exception when calling WireguardApi->createProfile: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **request** | [**WireGuardProfileCreateRequest**](WireGuardProfileCreateRequest.md)|  | [optional] 

### Return type

[**WireguardProfile**](WireguardProfile.md)

### Authorization

[Bearer](../README.md#Bearer)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **deleteProfile**
> deleteProfile(profileId)

Delete WireGuarg profile

### Example 
```dart
import 'package:forestvpn_api/api.dart';
// TODO Configure API key authorization: Bearer
//defaultApiClient.getAuthentication<ApiKeyAuth>('Bearer').apiKey = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//defaultApiClient.getAuthentication<ApiKeyAuth>('Bearer').apiKeyPrefix = 'Bearer';

var api_instance = WireguardApi();
var profileId = 38400000-8cf0-11bd-b23e-10b96e4ef00d; // String | 

try { 
    api_instance.deleteProfile(profileId);
} catch (e) {
    print("Exception when calling WireguardApi->deleteProfile: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **profileId** | [**String**](.md)|  | [default to null]

### Return type

void (empty response body)

### Authorization

[Bearer](../README.md#Bearer)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **getPeers**
> List<WireguardPeer> getPeers(timestamp)

Retrieve Wireguard peers

### Example 
```dart
import 'package:forestvpn_api/api.dart';
// TODO Configure API key authorization: Bearer
//defaultApiClient.getAuthentication<ApiKeyAuth>('Bearer').apiKey = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//defaultApiClient.getAuthentication<ApiKeyAuth>('Bearer').apiKeyPrefix = 'Bearer';

var api_instance = WireguardApi();
var timestamp = 56; // int | 

try { 
    var result = api_instance.getPeers(timestamp);
    print(result);
} catch (e) {
    print("Exception when calling WireguardApi->getPeers: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **timestamp** | **int**|  | [optional] [default to null]

### Return type

[**List<WireguardPeer>**](WireguardPeer.md)

### Authorization

[Bearer](../README.md#Bearer)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **getProfile**
> WireguardProfile getProfile()

Retrieve VPN profile

### Example 
```dart
import 'package:forestvpn_api/api.dart';
// TODO Configure API key authorization: Bearer
//defaultApiClient.getAuthentication<ApiKeyAuth>('Bearer').apiKey = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//defaultApiClient.getAuthentication<ApiKeyAuth>('Bearer').apiKeyPrefix = 'Bearer';

var api_instance = WireguardApi();

try { 
    var result = api_instance.getProfile();
    print(result);
} catch (e) {
    print("Exception when calling WireguardApi->getProfile: $e\n");
}
```

### Parameters
This endpoint does not need any parameter.

### Return type

[**WireguardProfile**](WireguardProfile.md)

### Authorization

[Bearer](../README.md#Bearer)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **getProfileByID**
> WireguardProfile getProfileByID(profileId)

Retrieve WireGuarg profile

### Example 
```dart
import 'package:forestvpn_api/api.dart';
// TODO Configure API key authorization: Bearer
//defaultApiClient.getAuthentication<ApiKeyAuth>('Bearer').apiKey = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//defaultApiClient.getAuthentication<ApiKeyAuth>('Bearer').apiKeyPrefix = 'Bearer';

var api_instance = WireguardApi();
var profileId = 38400000-8cf0-11bd-b23e-10b96e4ef00d; // String | 

try { 
    var result = api_instance.getProfileByID(profileId);
    print(result);
} catch (e) {
    print("Exception when calling WireguardApi->getProfileByID: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **profileId** | [**String**](.md)|  | [default to null]

### Return type

[**WireguardProfile**](WireguardProfile.md)

### Authorization

[Bearer](../README.md#Bearer)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **getProfiles**
> List<WireguardProfile> getProfiles()

Retrieve list of WireGuard profiles

### Example 
```dart
import 'package:forestvpn_api/api.dart';
// TODO Configure API key authorization: Bearer
//defaultApiClient.getAuthentication<ApiKeyAuth>('Bearer').apiKey = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//defaultApiClient.getAuthentication<ApiKeyAuth>('Bearer').apiKeyPrefix = 'Bearer';

var api_instance = WireguardApi();

try { 
    var result = api_instance.getProfiles();
    print(result);
} catch (e) {
    print("Exception when calling WireguardApi->getProfiles: $e\n");
}
```

### Parameters
This endpoint does not need any parameter.

### Return type

[**List<WireguardProfile>**](WireguardProfile.md)

### Authorization

[Bearer](../README.md#Bearer)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)
